==> sdk-3.2.0-sources.jar: com/kontakt/sdk/android/ble/service/DefaultBluetoothDeviceDiscoverer.java <==
package com.kontakt.sdk.android.ble.service;

import android.bluetooth.BluetoothDevice;
import com.kontakt.sdk.android.ble.configuration.scan.ScanContext;
import com.kontakt.sdk.android.ble.discovery.BluetoothDeviceDiscoverer;
import com.kontakt.sdk.android.ble.discovery.DiscoveryContract;
import com.kontakt.sdk.android.ble.discovery.eddystone.EddystoneDiscoverer;
import com.kontakt.sdk.android.ble.discovery.ibeacon.IBeaconDiscoverer;
import com.kontakt.sdk.android.ble.discovery.secure_profile.SecureProfileDiscoverer;
import com.kontakt.sdk.android.common.profile.DeviceProfile;
import java.util.ArrayList;
import java.util.Collection;

final class DefaultBluetoothDeviceDiscoverer implements BluetoothDeviceDiscoverer {

  private final Collection<BluetoothDeviceDiscoverer> discoverers = new ArrayList<>();

  DefaultBluetoothDeviceDiscoverer(ScanContext scanContext, DiscoveryContract discoveryContract) {
    if (scanContext.getObservedProfiles().contains(DeviceProfile.IBEACON)) {
      discoverers.add(new IBeaconDiscoverer(scanContext, discoveryContract));
    }

    if (scanContext.getObservedProfiles().contains(DeviceProfile.EDDYSTONE)) {
      discoverers.add(new EddystoneDiscoverer(scanContext, discoveryContract));
    }

    if (scanContext.getObservedProfiles().contains(DeviceProfile.KONTAKT_SECURE)) {
      discoverers.add(new SecureProfileDiscoverer(scanContext, discoveryContract));
    }
  }

  @Override
  public boolean performDiscovery(BluetoothDevice bluetoothDevice, int rssi, byte[] scanResult) {
    for (BluetoothDeviceDiscoverer discoverer : discoverers) {
      if (discoverer.performDiscovery(bluetoothDevice, rssi, scanResult)) {
        return true;
      }
    }
    return false;
  }

  @Override
  public void disable() {
    for (BluetoothDeviceDiscoverer discoverer : discoverers) {
      discoverer.disable();
    }
  }

  @Override
  public synchronized void evictInactiveDevices(long currentTimeMillis) {
    for (BluetoothDeviceDiscoverer discoverer : discoverers) {
      discoverer.evictInactiveDevices(currentTimeMillis);
    }
  }
}

==> sdk-3.2.2-sources.jar: com/kontakt/sdk/android/ble/service/DefaultBluetoothDeviceDiscoverer.java <==
package com.kontakt.sdk.android.ble.service;

import android.bluetooth.BluetoothDevice;
import com.kontakt.sdk.android.ble.cache.FutureShufflesCache;
import com.kontakt.sdk.android.ble.configuration.ScanContext;
import com.kontakt.sdk.android.ble.discovery.BluetoothDeviceDiscoverer;
import com.kontakt.sdk.android.ble.discovery.DiscoveryContract;
import com.kontakt.sdk.android.ble.discovery.eddystone.EddystoneDiscoverer;
import com.kontakt.sdk.android.ble.discovery.ibeacon.IBeaconDiscoverer;
import com.kontakt.sdk.android.ble.discovery.secure_profile.SecureProfileDiscoverer;
import com.kontakt.sdk.android.common.profile.DeviceProfile;
import java.util.ArrayList;
import java.util.Collection;

final class DefaultBluetoothDeviceDiscoverer implements BluetoothDeviceDiscoverer {

  private final Collection<BluetoothDeviceDiscoverer> discoverers = new ArrayList<>();

  DefaultBluetoothDeviceDiscoverer(ScanContext scanContext, DiscoveryContract discoveryContract, FutureShufflesCache cache) {
    if (scanContext.getObservedProfiles().contains(DeviceProfile.IBEACON)) {
      discoverers.add(new IBeaconDiscoverer(scanContext, discoveryContract, cache));
    }

    if (scanContext.getObservedProfiles().contains(DeviceProfile.EDDYSTONE)) {
      discoverers.add(new EddystoneDiscoverer(discoveryContract, scanContext, cache));
    }

    if (scanContext.getObservedProfiles().contains(DeviceProfile.KONTAKT_SECURE)) {
      discoverers.add(new SecureProfileDiscoverer(scanContext, discoveryContract, cache));
    }
  }

  @Override
  public void performDiscovery(BluetoothDevice bluetoothDevice, int rssi, byte[] scanResult) {
    for (BluetoothDeviceDiscoverer discoverer : discoverers) {
      discoverer.performDiscovery(bluetoothDevice, rssi, scanResult);
    }
  }

  @Override
  public void disable() {
    for (BluetoothDeviceDiscoverer discoverer : discoverers) {
      discoverer.disable();
    }
  }

  @Override
  public synchronized void evictInactiveDevices(long currentTimeMillis) {
    for (BluetoothDeviceDiscoverer discoverer : discoverers) {
      discoverer.evictInactiveDevices(currentTimeMillis);
    }
  }
}
